@@ -196,8 +196,9 @@ def plot_array(
     )
 
     plotter_util.set_title(title=title, titlesize=titlesize)
-    plotter_util.set_xy_labels_and_ticksize(
-        unit_label=unit_label,
+    plotter_util.set_yx_labels_and_ticksize(
+        unit_label_y=unit_label,
+        unit_label_x=unit_label,
         xlabelsize=xlabelsize,
         ylabelsize=ylabelsize,
         xyticksize=xyticksize,
@@ -387,7 +388,13 @@ def plot_origin(array, include_origin):
     """
     if include_origin:
 
-        plt.scatter(y=np.asarray(array.origin[0]), x=np.asarray(array.origin[1]), s=80, c="k", marker="x")
+        plt.scatter(
+            y=np.asarray(array.origin[0]),
+            x=np.asarray(array.origin[1]),
+            s=80,
+            c="k",
+            marker="x",
+        )
 
 
 def plot_centres(centres):
