@@ -103,8 +103,9 @@ def pixelization_1d_index_for_voronoi_sub_mask_1d_index_from_grids_and_geometry(
                 ]
 
                 separation_from_neighbor = (
-                                                   grid[sub_mask_1d_index, 0] - pixelization_grid[neighbor, 0]
-                ) ** 2 + (grid[sub_mask_1d_index, 1] - pixelization_grid[neighbor, 1]) ** 2
+                    (grid[sub_mask_1d_index, 0] - pixelization_grid[neighbor, 0]) ** 2
+                    + (grid[sub_mask_1d_index, 1] - pixelization_grid[neighbor, 1]) ** 2
+                )
 
                 if (
                     separation_from_neighbor
@@ -155,7 +156,7 @@ def adaptive_pixel_signals_from_images(
     'relative' signal (i.e. a pixel with 10 pixels doesn't have x2 the signal of one with 5).
 
     2) Divided by the maximum pixel-signal, so that all signals vary between 0 and 1. This ensures that the \
-    regularizations weights are defined identically for any datas_ units or signal-to-noise_map ratio.
+    regularizations weights are defined identically for any datas_ unit_label or signal-to-noise_map ratio.
 
     3) Raised to the power of the hyper_galaxy-parameter *signal_scale*, so the method can control the relative \
     contribution regularization in different regions of pixelization.
