@@ -14,24 +14,22 @@ class TestImagingFit:
             pixel_scales=(1.0, 1.0),
         )
 
-        data = aa.masked_array.manual_1d(
+        data = aa.masked.array.manual_1d(
             array=np.array([1.0, 2.0, 3.0, 4.0]), mask=mask
         )
-        noise_map = aa.masked_array.manual_1d(
+        noise_map = aa.masked.array.manual_1d(
             array=np.array([2.0, 2.0, 2.0, 2.0]), mask=mask
         )
 
         imaging = aa.imaging(image=data, noise_map=noise_map)
 
-        masked_imaging = aa.masked_imaging(imaging=imaging, mask=mask)
+        masked_imaging = aa.masked.imaging(imaging=imaging, mask=mask)
 
-        model_data = aa.masked_array.manual_1d(
+        model_data = aa.masked.array.manual_1d(
             array=np.array([1.0, 2.0, 3.0, 4.0]), mask=mask
         )
 
-        fit = aa.fit_imaging(
-            mask=mask, image=data, noise_map=noise_map, model_image=model_data
-        )
+        fit = aa.fit(masked_dataset=masked_imaging, model_data=model_data)
 
         assert (fit.mask == np.array([[False, False], [False, False]])).all()
 
@@ -53,10 +51,10 @@ class TestImagingFit:
         assert (fit.residual_map.in_2d == np.array([[0.0, 0.0], [0.0, 0.0]])).all()
 
         assert (
-            fit.normalized_residual_map.in_1d == np.array([0.0, 0.0, 0.0, 0.0])
+                fit.normalized_residual_map.in_1d == np.array([0.0, 0.0, 0.0, 0.0])
         ).all()
         assert (
-            fit.normalized_residual_map.in_2d == np.array([[0.0, 0.0], [0.0, 0.0]])
+                fit.normalized_residual_map.in_2d == np.array([[0.0, 0.0], [0.0, 0.0]])
         ).all()
 
         assert (fit.chi_squared_map.in_1d == np.array([0.0, 0.0, 0.0, 0.0])).all()
@@ -77,22 +75,20 @@ class TestImagingFit:
             pixel_scales=(1.0, 1.0),
         )
 
-        data = aa.masked_array.manual_1d(array=np.array([1.0, 2.0, 4.0]), mask=mask)
-        noise_map = aa.masked_array.manual_1d(
+        data = aa.masked.array.manual_1d(array=np.array([1.0, 2.0, 4.0]), mask=mask)
+        noise_map = aa.masked.array.manual_1d(
             array=np.array([2.0, 2.0, 2.0]), mask=mask
         )
 
         imaging = aa.imaging(image=data, noise_map=noise_map)
 
-        masked_imaging = aa.masked_imaging(imaging=imaging, mask=mask)
+        masked_imaging = aa.masked.imaging(imaging=imaging, mask=mask)
 
-        model_data = aa.masked_array.manual_1d(
+        model_data = aa.masked.array.manual_1d(
             array=np.array([1.0, 2.0, 3.0]), mask=mask
         )
 
-        fit = aa.fit_imaging(
-            mask=mask, image=data, noise_map=noise_map, model_image=model_data
-        )
+        fit = aa.fit(masked_dataset=masked_imaging, model_data=model_data)
 
         assert (fit.mask == np.array([[False, False], [True, False]])).all()
 
@@ -115,7 +111,7 @@ class TestImagingFit:
 
         assert (fit.normalized_residual_map.in_1d == np.array([0.0, 0.0, 0.5])).all()
         assert (
-            fit.normalized_residual_map.in_2d == np.array([[0.0, 0.0], [0.0, 0.5]])
+                fit.normalized_residual_map.in_2d == np.array([[0.0, 0.0], [0.0, 0.5]])
         ).all()
 
         assert (fit.chi_squared_map.in_1d == np.array([0.0, 0.0, 0.25])).all()
@@ -136,18 +132,18 @@ class TestImagingFit:
             pixel_scales=(1.0, 1.0),
         )
 
-        data = aa.masked_array.manual_1d(
+        data = aa.masked.array.manual_1d(
             array=np.array([1.0, 2.0, 3.0, 4.0]), mask=mask
         )
-        noise_map = aa.masked_array.manual_1d(
+        noise_map = aa.masked.array.manual_1d(
             array=np.array([2.0, 2.0, 2.0, 2.0]), mask=mask
         )
 
         imaging = aa.imaging(image=data, noise_map=noise_map)
 
-        masked_imaging = aa.masked_imaging(imaging=imaging, mask=mask)
+        masked_imaging = aa.masked.imaging(imaging=imaging, mask=mask)
 
-        model_data = aa.masked_array.manual_1d(
+        model_data = aa.masked.array.manual_1d(
             array=np.array([1.0, 2.0, 3.0, 4.0]), mask=mask
         )
 
@@ -158,11 +154,7 @@ class TestImagingFit:
         )
 
         fit = aa.fit(
-            mask=mask,
-            data=data,
-            noise_map=noise_map,
-            model_data=model_data,
-            inversion=inversion,
+            masked_dataset=masked_imaging, model_data=model_data, inversion=inversion
         )
 
         assert fit.chi_squared == 0.0
@@ -197,18 +189,13 @@ class TestInterferometerFit:
             visibilities=data, noise_map=noise_map, uv_wavelengths=np.ones(shape=(2, 2))
         )
 
-        masked_interferometer = aa.masked_interferometer(
+        masked_interferometer = aa.masked.interferometer(
             interferometer=interferometer, real_space_mask=mask
         )
 
         model_data = aa.visibilities.manual_1d(visibilities=[[1.0, 2.0], [3.0, 4.0]])
 
-        fit = aa.fit_interferometer(
-            visibilities_mask=masked_interferometer.visibilities_mask,
-            visibilities=data,
-            noise_map=noise_map,
-            model_visibilities=model_data,
-        )
+        fit = aa.fit(masked_dataset=masked_interferometer, model_data=model_data)
 
         assert (
             fit.visibilities_mask == np.array([[False, False], [False, False]])
@@ -229,7 +216,7 @@ class TestInterferometerFit:
         assert (fit.residual_map.in_1d == np.array([[0.0, 0.0], [0.0, 0.0]])).all()
 
         assert (
-            fit.normalized_residual_map.in_1d == np.array([[0.0, 0.0], [0.0, 0.0]])
+                fit.normalized_residual_map.in_1d == np.array([[0.0, 0.0], [0.0, 0.0]])
         ).all()
 
         assert (fit.chi_squared_map.in_1d == np.array([[0.0, 0.0], [0.0, 0.0]])).all()
@@ -256,18 +243,13 @@ class TestInterferometerFit:
             visibilities=data, noise_map=noise_map, uv_wavelengths=np.ones(shape=(2, 2))
         )
 
-        masked_interferometer = aa.masked_interferometer(
+        masked_interferometer = aa.masked.interferometer(
             interferometer=interferometer, real_space_mask=mask
         )
 
         model_data = aa.visibilities.manual_1d(visibilities=[[1.0, 2.0], [3.0, 3.0]])
 
-        fit = aa.fit_interferometer(
-            visibilities_mask=masked_interferometer.visibilities_mask,
-            visibilities=data,
-            noise_map=noise_map,
-            model_visibilities=model_data,
-        )
+        fit = aa.fit(masked_dataset=masked_interferometer, model_data=model_data)
 
         assert (
             fit.visibilities_mask == np.array([[False, False], [False, False]])
@@ -288,7 +270,7 @@ class TestInterferometerFit:
         assert (fit.residual_map.in_1d == np.array([[0.0, 0.0], [0.0, 1.0]])).all()
 
         assert (
-            fit.normalized_residual_map.in_1d == np.array([[0.0, 0.0], [0.0, 0.5]])
+                fit.normalized_residual_map.in_1d == np.array([[0.0, 0.0], [0.0, 0.5]])
         ).all()
 
         assert (fit.chi_squared_map.in_1d == np.array([[0.0, 0.0], [0.0, 0.25]])).all()
@@ -315,7 +297,7 @@ class TestInterferometerFit:
             visibilities=data, noise_map=noise_map, uv_wavelengths=np.ones(shape=(2, 2))
         )
 
-        masked_interferometer = aa.masked_interferometer(
+        masked_interferometer = aa.masked.interferometer(
             interferometer=interferometer, real_space_mask=mask
         )
 
@@ -327,11 +309,9 @@ class TestInterferometerFit:
             log_det_regularization_matrix_term=4.0,
         )
 
-        fit = aa.fit_interferometer(
-            visibilities_mask=masked_interferometer.visibilities_mask,
-            visibilities=data,
-            noise_map=noise_map,
-            model_visibilities=model_data,
+        fit = aa.fit(
+            masked_dataset=masked_interferometer,
+            model_data=model_data,
             inversion=inversion,
         )
 
